@@ -310,7 +310,9 @@ class MovementManager:
         """
         to_page = self.find_page(query=to)
         self.log.debug(f"Direct jump to {to_page}. Skipping all normal move function.")
-        if self.exp.config.getboolean("data", "record_move_history"):
+        if not self.exp.start_time:
+            pass
+        elif self.exp.config.getboolean("data", "record_move_history"):
                 self.record_move(self.current_page.is_closed, direction="jump", to_page=to_page)
          
         self.current_index = self.index_of(to_page)
@@ -529,6 +531,9 @@ class UserInterface:
             logo = self.exp.subpath(self.exp.config.get("layout_goe", "logo"))
             if logo.is_file():
                 self.config["logo_url"] = self.add_static_file(logo, content_type="image/png")
+            else:
+                with importlib.resources.path(img, "alfred_logo_color.png") as logo:    
+                    self.config["logo_url"] = self.add_static_file(logo, content_type="image/png")
 
         elif style == "goe":
 
